@@ -15,6 +15,7 @@ import logging
 import argparse
 import random
 from collections import defaultdict, namedtuple
+from functools import wraps
 import queue
 from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
 from threading import Event
@@ -84,10 +85,13 @@ class Queue(queue.Queue):
 
 
 def error():
+    """Return true if error occured."""
     return ERROR.is_set()
 
 
 def error_handler(func):
+    """Decorator for error handling."""
+    @wraps(func)
     def wrapper(*args, **kwargs):
         try:
             func(*args, **kwargs)
@@ -101,6 +105,7 @@ def error_handler(func):
 
 
 def term_handler(*args):
+    """Handle termination on user request."""
     logging.info("Terminating PEANUT on user request.")
     ERROR.set()
 
@@ -115,6 +120,7 @@ def create_index(
     min_repeat_count=1000,
     blocksize=512,
     statspath=None):
+    """Create a PEANUT index for the given reference."""
 
     cldevice = CLDevice(cpu=cpu)
     stats.cl = cldevice
@@ -152,6 +158,8 @@ def map_queries(
     paired=False,
     insert_size=220,
     insert_size_error=50):
+    """Map given queries to reference."""
+
     random.seed(SEED_MAPPING)
 
     with peanut.input.open_hdf5(indexpath) as hdf5file, ThreadPoolExecutor(max_workers=3) as pool:
@@ -190,12 +198,13 @@ def map_queries(
 
 @error_handler
 def eat_queue(queue):
-        while not error():
-            item = queue.get()
-            if item is QUEUE_SENTINEL:
-                queue.task_done()
-                return
+    """Dummy function to terminate queue."""
+    while not error():
+        item = queue.get()
+        if item is QUEUE_SENTINEL:
             queue.task_done()
+            return
+        queue.task_done()
 
 
 @error_handler
@@ -209,6 +218,7 @@ def _map_queries(
     blocksize_filtration=512,
     blocksize_validation=512,
     min_score=40):
+    """Worker for mapping queries."""
 
     cl = CLDevice(cpu=cpu)
     stats.cl = cl
@@ -314,6 +324,7 @@ def _postprocess_hits(
     insert_size=220,
     insert_size_error=50,
     accurate_mapq=False):
+    """Worker for postprocessing."""
 
     processed = 0
     while True:
@@ -351,6 +362,8 @@ def _write_hits(
     paired=False,
     use_xa=False
     ):
+    """Worker for writing."""
+
     peanut.output.print_sam_header(references, read_group)
     while True:
         item = bam_queue.get()
@@ -367,6 +380,7 @@ def _write_hits(
 
 
 def argument_parser():
+    """Setup the CLI argument parser."""
     p = argparse.ArgumentParser(description=__doc__)
     group = p.add_argument_group("technical parameters")
     group.add_argument("--profile", metavar="PATH", help="Activate profiling and write profile into FILE. Requires yappi.")
@@ -434,6 +448,7 @@ def argument_parser():
 
 
 def main(profile=False):
+    """Run PEANUT."""
     parser = argument_parser()
     args = parser.parse_args()
 
@@ -470,7 +485,10 @@ def main(profile=False):
                     print("Strata must be either all or a positive number.", file=sys.stderr)
                     exit(1)
 
+            query_buffer = args.query_buffer
             paired = args.paired or args.mates
+            if paired and query_buffer % 2:
+                query_buffer += 1
 
             map_queries(
                 args.queries,
@@ -485,7 +503,7 @@ def main(profile=False):
                 gap_extend_penalty=args.gap_extend_penalty,
                 blocksize_filtration=args.blocksize_filtration,
                 blocksize_validation=args.blocksize_validation,
-                query_buffersize=args.query_buffer,
+                query_buffersize=query_buffer,
                 hits_buffersize=args.hits_buffer,
                 statspath=args.stats,
                 threads=args.threads,
